@@ -116,7 +116,7 @@ print_file(addr, full)
 	mprintf(FPTR " ", addr);
 
 	mprintf(FPTR " " FPTR " ", f.f_dentry, f.f_op);
-	switch (f.f_mode) {
+	switch (f.f_mode & O_ACCMODE) {
 	case 0:	mprintf(" -");	break;
 	case 1: mprintf("r ");	break;
 	case 2: mprintf(" w");	break;
@@ -640,14 +640,27 @@ print_file_lock(addr, full, chain)
 				fl.fl_wait.task_list.prev);
 		}
 #endif
+#ifdef _file_lock_has_fl_ops
+		mprintf("  ops:        " FPTR "\n", fl.fl_ops);
+#endif
+#ifdef _file_lock_has_fl_lmops
+		mprintf("  lmops:      " FPTR "\n", fl.fl_lmops);
+#endif
+#ifdef _file_lock_has_fl_notify
 		mprintf("  not/ins/rem:" FPTR " " FPTR " " FPTR "\n",
 			fl.fl_notify, fl.fl_insert, fl.fl_remove);
+#endif
 		mprintf("  fasync:     " FPTR "\n", fl.fl_fasync);
 		mprintf("  break_time: %8lx\n", fl.fl_break_time);
 		mprintf("  nfs_fl:     %x  %x  %lx\n",
 			fl.fl_u.nfs_fl.state,
 			fl.fl_u.nfs_fl.flags,
-			fl.fl_u.nfs_fl.host);
+#ifdef _file_lock_has_fl_ops
+			fl.fl_u.nfs_fl.owner
+#else
+			fl.fl_u.nfs_fl.host
+#endif
+			);
 	}
 
 	switch (chain) {
