@@ -156,7 +156,7 @@ print_sk_buff(addr)
 	mprintf(" " FPTR, skb.dev);
 	mprintf(" " FPTR, skb.h.th);
 	mprintf(" " FPTR, skb.nh.iph);
-	mprintf(" " FPTR, skb.mac.ethernet);
+	mprintf(" " FPTR, skb.mac.raw);
 	mprintf(" " FPTR, skb.dst);
 	mprintf(" %4x %4x", skb.len, skb.data_len);
 	mprintf(" " FPTR, skb.head);
@@ -179,9 +179,6 @@ print_sock(addr, fflag)
 	mprintf(" %6s", get_socket_type(sk.sk_type));
 	mprintf(" %3x %1x", ATOMIC_READ(sk.sk_rmem_alloc), sk.sk_receive_queue.qlen);
 	mprintf(" %3x %1x", ATOMIC_READ(sk.sk_wmem_alloc), sk.sk_write_queue.qlen);
-#if 0
-	mprintf(" " FPTR, sk.sk_pair);
-#endif
 	mprintf(" " FPTR, sk.sk_socket);
 	mprintbit(soflags, sk.sk_flags);
 	mprintf("\n");
@@ -199,7 +196,6 @@ print_sock(addr, fflag)
 		mprintf("\tsleep           " FPTR "\n", sk.sk_sleep);
 		mprintf("\tdst_cache       " FPTR "\n", sk.sk_dst_cache);
 		mprintf("\tlingertime      %lx\n", sk.sk_lingertime);
-		mprintf("\tpair            " FPTR "\n", sk.sk_pair);
 		mprintf("\tbacklog         " FPTR "  " FPTR "\n",
 			sk.sk_backlog.head, sk.sk_backlog.tail);
 		mprintf("\tprot            " FPTR "\n", sk.sk_prot);
