@@ -111,8 +111,18 @@ print_task(addr, full)
 	case TASK_INTERRUPTIBLE:	c = 'I';	break;
 	case TASK_UNINTERRUPTIBLE:	c = 'U';	break;
 	case TASK_STOPPED:		c = 'T';	break;
+#ifdef TASK_ZOMBIE
 	case TASK_ZOMBIE:		c = 'Z';	break;
+#endif
+#ifdef TASK_DEAD
 	case TASK_DEAD:			c = 'D';	break;
+#endif
+#ifdef EXIT_ZOMBIE
+	case EXIT_ZOMBIE:		c = 'Z';	break;
+#endif
+#ifdef EXIT_DEAD
+	case EXIT_DEAD:			c = 'D';	break;
+#endif
 	default:			c = '?';	break;
 	}
 #ifdef _task_struct_has_session
@@ -152,8 +162,12 @@ print_task(addr, full)
 	mprintf("\tmm:         " FPTR "  (mm_struct)\n",   ts.mm);
 	mprintf("\tbinfmt:     " FPTR "  (binfmt)\n",      ts.binfmt);
 	mprintf("\tparent:     " FPTR "  (task_struct)\n", ts.parent);
+#ifdef _task_struct_has_cutime
 	mprintf("\ttimes:      %lx %lx - %lx %lx\n",
 		ts.utime, ts.stime, ts.cutime, ts.cstime);
+#else
+	mprintf("\ttimes:      %lx %lx\n", ts.utime, ts.stime);
+#endif
 	mprintf("\tstart_time: %llx\n", ts.start_time);
 	mprintf("\tcap:        %x\n", ts.cap_effective);
 	mprintf("\tuser:       " FPTR "  (user_struct)\n", ts.user);
