@@ -21,6 +21,7 @@
 #include <linux/net.h>
 #include <linux/nfs_fs.h>
 #include <linux/socket.h>
+#include <linux/skbuff.h>
 #if defined(CONFIG_SUNRPC) || defined(CONFIG_SUNRPC_MODULE)
 #include <linux/sunrpc/svc.h>
 #endif
@@ -99,6 +100,7 @@ struct sizetbl sizetbl[] = {
 	{ "sigpending",		sizeof(struct sigpending) },
 	{ "sigset_t",		sizeof(sigset_t) },
 	{ "size_t",		sizeof(size_t) },
+	{ "sk_buff",		sizeof(struct sk_buff) },
 	{ "slab",		sizeof(struct slab) },
 	{ "sockaddr",		sizeof(struct sockaddr) },
 #if defined(CONFIG_INET)
