@@ -44,6 +44,9 @@ PRIVATE const char *file_op[] = {
 #endif
 #ifdef _file_operations_has_check_flags
 	"check_flags", "dir_notify",
+#endif
+#ifdef _file_operations_has_flock
+	"flock",
 #endif
 	NULL
 };
