@@ -736,7 +736,7 @@ getsib(mod, cur, nb)
 }
 
 const char *
-getaddrmod(w, cur, nb)
+getvaluemod(w, cur, nb)
 int w;
 unsigned const char *cur;
 int *nb;
@@ -854,7 +854,7 @@ int *nb;
 		sprintf(buf, s, *cur & 7);
 		return buf;
 	}
-	s = getaddrmod(1, cur, nb);
+	s = getvaluemod(1, cur, nb);
 	if ((op = npx_opt[c & 7][(*cur / 8) & 7]) == 0)
 		return NULL;
 	sprintf(buf, "%s %s", op, s);
@@ -1019,11 +1019,11 @@ getop2_0f(addr, cur, nb)
 		sprintf(buf, p->op, opad);
 		return buf;
 	case SET:
-		sprintf(buf, p->op, getaddrmod(1, cur + 1, nb));
+		sprintf(buf, p->op, getvaluemod(1, cur + 1, nb));
 		return buf;
 	case MOD0_4:
 		sprintf(buf, p->op,
-			getaddrmod(1, cur + 1, nb),
+			getvaluemod(1, cur + 1, nb),
 			opsize? getreg16((cur[1] >> 3) & 7):
 				getreg32((cur[1] >> 3) & 7));
 		return buf;
@@ -1031,7 +1031,7 @@ getop2_0f(addr, cur, nb)
 		sprintf(buf, p->op,
 			opsize? getreg16((cur[1] >> 3) & 7):
 				getreg32((cur[1] >> 3) & 7),
-			getaddrmod(1, cur + 1, nb));
+			getvaluemod(1, cur + 1, nb));
 		return buf;
 	case CREG0:
 		sprintf(buf, p->op,
@@ -1044,24 +1044,24 @@ getop2_0f(addr, cur, nb)
 			getreg32(cur[1] & 7));
 		return buf;
 	case GROUPF:
-		s = getaddrmod(1, cur + 1, nb);
+		s = getvaluemod(1, cur + 1, nb);
 		sprintf(buf, get_groupf_op((cur[1] >> 3) & 7), s);
 		return buf;
 	case GROUPG:
-		s = getaddrmod(1, cur + 1, nb);
+		s = getvaluemod(1, cur + 1, nb);
 		sprintf(buf, get_groupg_op((cur[1] >> 3) & 7), s);
 		return buf;
 	case GROUPH:
-		s = getaddrmod(1, cur + 1, nb);
+		s = getvaluemod(1, cur + 1, nb);
 		sprintf(buf, get_grouph_op((cur[1] >> 3) & 7),
 			s, cur[*nb - 2]);
 		return buf;
 	case GROUP16:
-		s = getaddrmod(1, cur + 1, nb);
+		s = getvaluemod(1, cur + 1, nb);
 		sprintf(buf, get_group16_op((cur[1] >> 3) & 7), s);
 		return buf;
 	case ARG3:
-		s = getaddrmod(1, cur + 1, nb);
+		s = getvaluemod(1, cur + 1, nb);
 		if  (c & 1)
 			i = 0;
 		else {
@@ -1074,7 +1074,7 @@ getop2_0f(addr, cur, nb)
 			s, i);
 		return buf;
 	case MMX:
-		getaddrmod(1, cur + 1, nb);
+		getvaluemod(1, cur + 1, nb);
 		sprintf(buf, "? (%s)", p->op);
 		return buf;
 	case PREF:
@@ -1177,30 +1177,30 @@ print_dis(addr, first)
 		break;
 	case MOD0_1:
 		sprintf(prt, p->op,
-			getaddrmod(0, buf + 1, &nb),
+			getvaluemod(0, buf + 1, &nb),
 			getreg8((buf[1] >> 3) & 7));
 		break;
 	case MOD0_4:
 		sprintf(prt, p->op,
-			getaddrmod(1, buf + 1, &nb),
+			getvaluemod(1, buf + 1, &nb),
 			opsize? getreg16((buf[1] >> 3) & 7):
 				getreg32((buf[1] >> 3) & 7));
 		break;
 	case MOD1_1:
 		sprintf(prt, p->op, getreg8((buf[1] >> 3) & 7),
-			getaddrmod(0, buf + 1, &nb));
+			getvaluemod(0, buf + 1, &nb));
 		break;
 	case MOD1_4:
 		sprintf(prt, p->op,
 			opsize? getreg16((buf[1] >> 3) & 7):
 				getreg32((buf[1] >> 3) & 7),
-			getaddrmod(1, buf + 1, &nb));
+			getvaluemod(1, buf + 1, &nb));
 		break;
 	case OP2B:
 		strcpy(prt, getop2_0f(addr, buf + 1, &nb));
 		break;
 	case GROUPA:
-		s = getaddrmod(buf[0] & 1, buf + 1, &nb);
+		s = getvaluemod(buf[0] & 1, buf + 1, &nb);
 		switch (buf[0] & 3) {
 		case 0:	i = buf[nb];		nb += 1;	break;
 		case 1:	if (opsize) {
@@ -1217,7 +1217,7 @@ print_dis(addr, first)
 		sprintf(prt, get_groupa_op((buf[1] >> 3) & 7), s, i);
 		break;
 	case GROUPB:
-		s = getaddrmod(buf[0] & 1, buf + 1, &nb);
+		s = getvaluemod(buf[0] & 1, buf + 1, &nb);
 		sprintf(prt, get_groupb_op((buf[1] >> 3) & 7), s);
 		switch (buf[0]) {
 		case 0xc0: case 0xc1:
@@ -1229,7 +1229,7 @@ print_dis(addr, first)
 		}
 		break;
 	case GROUPC:	/* f6 or f7 */
-		s = getaddrmod(buf[0] & 1, buf + 1, &nb);
+		s = getvaluemod(buf[0] & 1, buf + 1, &nb);
 		switch ((buf[1] >> 3) & 7) {
 		case 0: case 1:
 			switch (buf[0] & 1) {
@@ -1249,15 +1249,15 @@ print_dis(addr, first)
 		sprintf(prt, get_groupc_op((buf[1] >> 3) & 7), s, i);
 		break;
 	case GROUPD:
-		s = getaddrmod(0, buf + 1, &nb);
+		s = getvaluemod(0, buf + 1, &nb);
 		sprintf(prt, get_groupd_op((buf[1] >> 3) & 7), s);
 		break;
 	case GROUPE:
-		s = getaddrmod(1, buf + 1, &nb);
+		s = getvaluemod(1, buf + 1, &nb);
 		sprintf(prt, get_groupe_op((buf[1] >> 3) & 7), s);
 		break;
 	case IMM:
-		s = getaddrmod(buf[0] & 1, buf + 1, &nb);
+		s = getvaluemod(buf[0] & 1, buf + 1, &nb);
 		switch (buf[0] & 1) {
 		case 0:	i = buf[nb];		nb += 1;	break;
 		case 1:	if (opsize) {
@@ -1274,11 +1274,11 @@ print_dis(addr, first)
 		sprintf(prt, p->op, s, i);
 		break;
 	case POP:
-		s = getaddrmod(1, buf + 1, &nb);
+		s = getvaluemod(1, buf + 1, &nb);
 		sprintf(prt, p->op, s);
 		break;
 	case IMUL:
-		s = getaddrmod(buf[0] & 1, buf + 1, &nb);
+		s = getvaluemod(buf[0] & 1, buf + 1, &nb);
 		switch (buf[0] & 2) {
 		case 2:	i = buf[nb];	nb += 1;	break;
 		case 0:	if (opsize) {
@@ -1297,13 +1297,13 @@ print_dis(addr, first)
 		break;
 	case SREG0:
 		sprintf(prt, p->op,
-			getaddrmod(1, buf + 1, &nb),
+			getvaluemod(1, buf + 1, &nb),
 			getsreg((buf[1] >> 3) & 7));
 		break;
 	case SREG1:
 		sprintf(prt, p->op,
 			getsreg((buf[1] >> 3) & 7),
-			getaddrmod(1, buf + 1, &nb));
+			getvaluemod(1, buf + 1, &nb));
 		break;
 	case OPSIZE:
 		sprintf(prt, "(%s)", p->op);
@@ -1352,9 +1352,9 @@ dis()
 		THROW(usage);
 	}
 
-	saddr = getaddr(args[1]);
+	saddr = getvalue(args[1]);
 	if (argcnt == 3) {
-		size = getaddr(args[2]);
+		size = getvalue(args[2]);
 	}
 
 	opsize = 0;
