@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -27,7 +27,7 @@ semaphore()
 
 	prhead_semaphore();
 	while (args[optind]) {
-		print_semaphore(getaddr(args[optind]));
+		print_semaphore(getvalue(args[optind]));
 		optind++;
 	}
 	return 0;
