@@ -234,9 +234,9 @@ init_sym()
 		if (strcmp(buf, "syscall_call") == 0)
 			continue;
 #endif
-#if 1
 		if (strcmp(buf, "_end") == 0)
 			end_addr = addr;
+#if 1
 		else if (end_addr == addr)
 			continue;
 #endif
@@ -246,7 +246,7 @@ init_sym()
 
 	/* available area (System.map must be sorted by address) */
 	kmem_low = symtable[0].addr & ~0x0ffffffful;
-	kmem_high = symtable[nsym - 1].addr;
+	kmem_high = end_addr? end_addr: symtable[nsym - 1].addr;
 
 #ifndef CONF_USE_LKCD
 	/* for default V-P transfer */
@@ -424,7 +424,7 @@ searchsym_byaddr(addr)
 		min = cached + 1;
 	} else {
 		/* cache hit */
-		if (symtable[cached].addr == kmem_high && addr != kmem_high)
+		if (addr > kmem_high && symtable[cached].addr != addr)
 			return NULL;
 		return &symtable[cached];
 	}
@@ -455,7 +455,7 @@ searchsym_byaddr(addr)
 	if (addr - symtable[min].addr > 4*1024*1024)
 		return NULL;
 #endif
-	if (symtable[min].addr == kmem_high && addr != kmem_high)
+	if (addr > kmem_high && symtable[cached].addr != addr)
 		return NULL;	/* between static-linked and module address */
 	return &symtable[min];
 }
